@@ -26,6 +26,8 @@ from appium.webdriver.common.multi_action import MultiAction
 
 from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.webelement import WebElement
+from selenium.webdriver.support.ui import WebDriverWait
+from selenium.common.exceptions import TimeoutException
 
 
 class WebDriver(webdriver.Remote):
@@ -196,7 +198,6 @@ class WebDriver(webdriver.Remote):
             x = positions[0][0]
             y = positions[0][1]
             if duration:
-                duration = duration
                 action.long_press(x=x, y=y, duration=duration).release()
             else:
                 action.tap(x=x, y=y)
@@ -208,7 +209,6 @@ class WebDriver(webdriver.Remote):
                 y = position[1]
                 action = TouchAction(self)
                 if duration:
-                    duration *= 1000  # we take seconds, but send milliseconds
                     action.long_press(x=x, y=y, duration=duration).release()
                 else:
                     action.press(x=x, y=y).release()
@@ -309,16 +309,19 @@ class WebDriver(webdriver.Remote):
         self.execute_script('mobile: pinchOpen', opts)
         return self
 
-    def app_strings(self, language=None):
+    def app_strings(self, language=None, string_file=None):
         """Returns the application strings from the device for the specified
         language.
 
         :Args:
          - language - strings language code
+         - string_file - the name of the string file to query
         """
         data = {}
         if language != None:
             data['language'] = language
+        if string_file != None:
+            data['stringFile'] = string_file
         return self.execute(Command.GET_APP_STRINGS, data)['value']
 
     def reset(self):
@@ -402,6 +405,24 @@ class WebDriver(webdriver.Remote):
         """
         return self.execute(Command.GET_CURRENT_ACTIVITY)['value']
 
+    def wait_activity(self, activity, timeout, interval=1):
+        """Wait for an activity: block until target activity presents
+        or time out.
+
+        This is an Android-only method.
+
+        :Agrs:
+         - activity - target activity
+         - timeout - max wait time, in seconds
+         - interval - sleep interval between retries, in seconds
+        """
+        try:
+            WebDriverWait(self, timeout, interval).until(
+                lambda d: d.current_activity == activity)
+            return True
+        except TimeoutException:
+            return False
+
     def set_value(self, element, value):
         """Set the value on an element in the application.
 
